@@ -28,8 +28,7 @@ the usage of the following ae namespace portions get demonstrated by this applic
 
 .. hint::
     the Kivy variant of this demo app uses additionally the following ae namespace portions: :mod:`ae.kivy_auto_width`,
-    :mod:`ae.kivy_dyn_chi`, :mod:`ae.kivy_help`, :mod:`ae.kivy_relief_canvas`, :mod:`ae.kivy_app` and
-    :mod:`ae.kivy_user_prefs`.
+    :mod:`ae.kivy_dyn_chi`, :mod:`ae.kivy_relief_canvas`, :mod:`ae.kivy` and :mod:`ae.kivy_user_prefs`.
 
 
 features of the lisz demo app
@@ -37,7 +36,7 @@ features of the lisz demo app
 
 * internationalization of texts, user messages, help texts, button/label texts (:mod:`ae.i18n`)
 * easy mapping of files in complex folder structures (:mod:`ae.files`, :mod:`ae.paths`)
-* providing help screens (:mod:`ae.gui_help`, :mod:`ae.kivy_help`)
+* providing help screens (:mod:`ae.gui_help`, :mod:`ae.kivy.widgets`)
 * colors changeable by user (:mod:`ae.kivy_user_prefs`, :mod:`ae.enaml_app`)
 * font and button sizes are changeable by user (:mod:`ae.gui_app`)
 * dark and light theme switchable by user
@@ -96,7 +95,7 @@ GUI framework demo implementations
 the plan is to integrate the following GUI frameworks on top of the :class:`abstract base class <~.gui_app.MainAppBase>`
 (implemented in the :mod:`ae.gui_app` portion of the `ae namespace <https://ae.readthedocs.io>`__):
 
-* :mod:`Kivy <ae.kivy_app>` based on the `kivy framework <https://kivy.org>`__:
+* :mod:`Kivy <ae.kivy>` based on the `kivy framework <https://kivy.org>`__:
   `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`__
 * :mod:`Enaml <ae.enaml_app>` based on `the enaml framework <https://enaml.readthedocs.io/en/latest/>`__:
   `enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`__
@@ -110,7 +109,7 @@ the plan is to integrate the following GUI frameworks on top of the :class:`abst
 
 the main app base mixin class :class:`LiszDataMixin` provided by this module is used to manage the common data
 structures, functions and methods for the various demo applications variants based on :mod:`ae.gui_app` and the related
-GUI framework implementation portions (like e.g. :mod:`ae.kivy_app` and :mod:`ae.enaml_app`) of the ae namespace.
+GUI framework implementation portions (like e.g. :mod:`ae.kivy.apps` and :mod:`ae.enaml_app`) of the ae namespace.
 
 
 gui framework implementation variants
@@ -228,7 +227,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, flow_path_strip, replace_flow_action  # type: ignore
 
 
-__version__ = '0.3.49'
+__version__ = '0.3.50'
 
 
 FLOW_PATH_ROOT_ID = '^^^^'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
